@@ -1,10 +1,10 @@
 ;;; zenburn-theme.el --- A low contrast color theme for Emacs.
 
-;; Copyright (C) 2011-2016 Bozhidar Batsov
+;; Copyright (C) 2011-2017 Bozhidar Batsov
 
 ;; Author: Bozhidar Batsov <bozhidar@batsov.com>
 ;; URL: http://github.com/bbatsov/zenburn-emacs
-;; Version: 2.4
+;; Version: 2.5
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 ;;; Commentary:
 
-;; A port of the popular Vim theme Zenburn for Emacs 24, built on top
+;; A port of the popular Vim theme Zenburn for Emacs 24+, built on top
 ;; of the new built-in theme support in Emacs 24.
 
 ;;; Credits:
@@ -109,7 +109,7 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(link-visited ((t (:foreground ,zenburn-yellow-2 :underline t :weight normal))))
    `(default ((t (:foreground ,zenburn-fg :background ,zenburn-bg))))
    `(cursor ((t (:foreground ,zenburn-fg :background ,zenburn-fg+1))))
-   `(escape-glyph ((t (:foreground ,zenburn-yellow :bold t))))
+   `(escape-glyph ((t (:foreground ,zenburn-yellow :weight bold))))
    `(fringe ((t (:foreground ,zenburn-fg :background ,zenburn-bg+1))))
    `(header-line ((t (:foreground ,zenburn-yellow
                                   :background ,zenburn-bg-1
@@ -141,6 +141,8 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(grep-hit-face ((t (:foreground ,zenburn-blue))))
    `(grep-match-face ((t (:foreground ,zenburn-orange :weight bold))))
    `(match ((t (:background ,zenburn-bg-1 :foreground ,zenburn-orange :weight bold))))
+;;;;; info
+   `(Info-quoted ((t (:inherit font-lock-constant-face))))
 ;;;;; isearch
    `(isearch ((t (:foreground ,zenburn-yellow-2 :weight bold :background ,zenburn-bg+2))))
    `(isearch-fail ((t (:foreground ,zenburn-fg :background ,zenburn-red-4))))
@@ -205,6 +207,10 @@ Also bind `class' to ((class color) (min-colors 89))."
      ((t (:foreground ,zenburn-fg-1 :background ,zenburn-bg :inverse-video nil))))
    `(ace-jump-face-foreground
      ((t (:foreground ,zenburn-green+2 :background ,zenburn-bg :inverse-video nil))))
+;;;;; ace-window
+   `(aw-background-face
+     ((t (:foreground ,zenburn-fg-1 :background ,zenburn-bg :inverse-video nil))))
+   `(aw-leading-char-face ((t (:inherit aw-mode-line-face))))
 ;;;;; android mode
    `(android-mode-debug-face ((t (:foreground ,zenburn-green+1))))
    `(android-mode-error-face ((t (:foreground ,zenburn-orange :weight bold))))
@@ -213,6 +219,11 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(android-mode-warning-face ((t (:foreground ,zenburn-yellow))))
 ;;;;; anzu
    `(anzu-mode-line ((t (:foreground ,zenburn-cyan :weight bold))))
+   `(anzu-mode-line-no-match ((t (:foreground ,zenburn-red :weight bold))))
+   `(anzu-match-1 ((t (:foreground ,zenburn-bg :background ,zenburn-green))))
+   `(anzu-match-2 ((t (:foreground ,zenburn-bg :background ,zenburn-orange))))
+   `(anzu-match-3 ((t (:foreground ,zenburn-bg :background ,zenburn-blue))))
+   `(anzu-replace-to ((t (:inherit anzu-replace-highlight :foreground ,zenburn-yellow))))
 ;;;;; auctex
    `(font-latex-bold-face ((t (:inherit bold))))
    `(font-latex-warning-face ((t (:foreground nil :inherit font-lock-warning-face))))
@@ -241,6 +252,8 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(ac-candidate-face ((t (:background ,zenburn-bg+3 :foreground ,zenburn-bg-2))))
    `(ac-selection-face ((t (:background ,zenburn-blue-4 :foreground ,zenburn-fg))))
    `(popup-tip-face ((t (:background ,zenburn-yellow-2 :foreground ,zenburn-bg-2))))
+   `(popup-menu-mouse-face ((t (:background ,zenburn-yellow-2 :foreground ,zenburn-bg-2))))
+   `(popup-summary-face ((t (:background ,zenburn-bg+3 :foreground ,zenburn-bg-2))))
    `(popup-scroll-bar-foreground-face ((t (:background ,zenburn-blue-5))))
    `(popup-scroll-bar-background-face ((t (:background ,zenburn-bg-1))))
    `(popup-isearch-match ((t (:background ,zenburn-bg :foreground ,zenburn-fg))))
@@ -272,8 +285,27 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(bm-fringe-face ((t (:background ,zenburn-yellow-1 :foreground ,zenburn-bg))))
    `(bm-fringe-persistent-face ((t (:background ,zenburn-green-1 :foreground ,zenburn-bg))))
    `(bm-persistent-face ((t (:background ,zenburn-green-1 :foreground ,zenburn-bg))))
+;;;;; calfw
+   `(cfw:face-annotation ((t (:foreground ,zenburn-red :inherit cfw:face-day-title))))
+   `(cfw:face-day-title ((t nil)))
+   `(cfw:face-default-content ((t (:foreground ,zenburn-green))))
+   `(cfw:face-default-day ((t (:weight bold))))
+   `(cfw:face-disable ((t (:foreground ,zenburn-fg-1))))
+   `(cfw:face-grid ((t (:inherit shadow))))
+   `(cfw:face-header ((t (:inherit font-lock-keyword-face))))
+   `(cfw:face-holiday ((t (:inherit cfw:face-sunday))))
+   `(cfw:face-periods ((t (:foreground ,zenburn-cyan))))
+   `(cfw:face-saturday ((t (:foreground ,zenburn-blue :weight bold))))
+   `(cfw:face-select ((t (:background ,zenburn-blue-5))))
+   `(cfw:face-sunday ((t (:foreground ,zenburn-red :weight bold))))
+   `(cfw:face-title ((t (:height 2.0 :inherit (variable-pitch font-lock-keyword-face)))))
+   `(cfw:face-today ((t (:foreground ,zenburn-cyan :weight bold))))
+   `(cfw:face-today-title ((t (:inherit highlight bold))))
+   `(cfw:face-toolbar ((t (:background ,zenburn-blue-5))))
+   `(cfw:face-toolbar-button-off ((t (:underline nil :inherit link))))
+   `(cfw:face-toolbar-button-on ((t (:underline nil :inherit link-visited))))
 ;;;;; cider
-   `(cider-result-overlay-face ((t (:foreground ,zenburn-fg-1 :background unspecified))))
+   `(cider-result-overlay-face ((t (:background unspecified))))
    `(cider-enlightened-face ((t (:box (:color ,zenburn-orange :line-width -1)))))
    `(cider-enlightened-local-face ((t (:weight bold :foreground ,zenburn-green+1))))
    `(cider-deprecated-face ((t (:background ,zenburn-yellow-2))))
@@ -308,6 +340,13 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(ctbl:face-cell-select ((t (:background ,zenburn-blue :foreground ,zenburn-bg))))
    `(ctbl:face-continue-bar ((t (:background ,zenburn-bg-05 :foreground ,zenburn-bg))))
    `(ctbl:face-row-select ((t (:background ,zenburn-cyan :foreground ,zenburn-bg))))
+;;;;; debbugs
+   `(debbugs-gnu-done ((t (:foreground ,zenburn-fg-1))))
+   `(debbugs-gnu-handled ((t (:foreground ,zenburn-green))))
+   `(debbugs-gnu-new ((t (:foreground ,zenburn-red))))
+   `(debbugs-gnu-pending ((t (:foreground ,zenburn-blue))))
+   `(debbugs-gnu-stale ((t (:foreground ,zenburn-orange))))
+   `(debbugs-gnu-tagged ((t (:foreground ,zenburn-red))))
 ;;;;; diff
    `(diff-added          ((t (:background "#335533" :foreground ,zenburn-green))))
    `(diff-changed        ((t (:background "#555511" :foreground ,zenburn-yellow-1))))
@@ -318,8 +357,8 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(diff-header ((,class (:background ,zenburn-bg+2))
                   (t (:background ,zenburn-fg :foreground ,zenburn-bg))))
    `(diff-file-header
-     ((,class (:background ,zenburn-bg+2 :foreground ,zenburn-fg :bold t))
-      (t (:background ,zenburn-fg :foreground ,zenburn-bg :bold t))))
+     ((,class (:background ,zenburn-bg+2 :foreground ,zenburn-fg :weight bold))
+      (t (:background ,zenburn-fg :foreground ,zenburn-bg :weight bold))))
 ;;;;; diff-hl
    `(diff-hl-change ((,class (:foreground ,zenburn-blue :background ,zenburn-blue-2))))
    `(diff-hl-delete ((,class (:foreground ,zenburn-red+1 :background ,zenburn-red-1))))
@@ -351,6 +390,10 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(diredp-read-priv ((t (:foreground ,zenburn-green-1))))
    `(diredp-symlink ((t (:foreground ,zenburn-yellow))))
    `(diredp-write-priv ((t (:foreground ,zenburn-magenta))))
+;;;;; dired-async
+   `(dired-async-failures ((t (:foreground ,zenburn-red :weight bold))))
+   `(dired-async-message ((t (:foreground ,zenburn-yellow :weight bold))))
+   `(dired-async-mode-message ((t (:foreground ,zenburn-yellow))))
 ;;;;; ediff
    `(ediff-current-diff-A ((t (:foreground ,zenburn-fg :background ,zenburn-red-4))))
    `(ediff-current-diff-Ancestor ((t (:foreground ,zenburn-fg :background ,zenburn-red-4))))
@@ -381,6 +424,9 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(egg-section-title ((t (:foreground ,zenburn-yellow))))
    `(egg-stash-mono ((t (:foreground ,zenburn-green+4))))
 ;;;;; elfeed
+   `(elfeed-log-error-level-face ((t (:foreground ,zenburn-red))))
+   `(elfeed-log-info-level-face ((t (:foreground ,zenburn-blue))))
+   `(elfeed-log-warn-level-face ((t (:foreground ,zenburn-yellow))))
    `(elfeed-search-date-face ((t (:foreground ,zenburn-yellow-1 :underline t
                                               :weight bold))))
    `(elfeed-search-tag-face ((t (:foreground ,zenburn-green))))
@@ -419,6 +465,8 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(erc-prompt-face ((t (:foreground ,zenburn-orange :background ,zenburn-bg :weight bold))))
    `(erc-timestamp-face ((t (:foreground ,zenburn-green+4))))
    `(erc-underline-face ((t (:underline t))))
+;;;;; eros
+   `(eros-result-overlay-face ((t (:background unspecified))))
 ;;;;; ert
    `(ert-test-result-expected ((t (:foreground ,zenburn-green+4 :background ,zenburn-bg))))
    `(ert-test-result-unexpected ((t (:foreground ,zenburn-red :background ,zenburn-bg))))
@@ -498,27 +546,27 @@ Also bind `class' to ((class color) (min-colors 89))."
 ;;;;; git-rebase
    `(git-rebase-hash ((t (:foreground, zenburn-orange))))
 ;;;;; gnus
-   `(gnus-group-mail-1 ((t (:bold t :inherit gnus-group-mail-1-empty))))
+   `(gnus-group-mail-1 ((t (:weight bold :inherit gnus-group-mail-1-empty))))
    `(gnus-group-mail-1-empty ((t (:inherit gnus-group-news-1-empty))))
-   `(gnus-group-mail-2 ((t (:bold t :inherit gnus-group-mail-2-empty))))
+   `(gnus-group-mail-2 ((t (:weight bold :inherit gnus-group-mail-2-empty))))
    `(gnus-group-mail-2-empty ((t (:inherit gnus-group-news-2-empty))))
-   `(gnus-group-mail-3 ((t (:bold t :inherit gnus-group-mail-3-empty))))
+   `(gnus-group-mail-3 ((t (:weight bold :inherit gnus-group-mail-3-empty))))
    `(gnus-group-mail-3-empty ((t (:inherit gnus-group-news-3-empty))))
-   `(gnus-group-mail-4 ((t (:bold t :inherit gnus-group-mail-4-empty))))
+   `(gnus-group-mail-4 ((t (:weight bold :inherit gnus-group-mail-4-empty))))
    `(gnus-group-mail-4-empty ((t (:inherit gnus-group-news-4-empty))))
-   `(gnus-group-mail-5 ((t (:bold t :inherit gnus-group-mail-5-empty))))
+   `(gnus-group-mail-5 ((t (:weight bold :inherit gnus-group-mail-5-empty))))
    `(gnus-group-mail-5-empty ((t (:inherit gnus-group-news-5-empty))))
-   `(gnus-group-mail-6 ((t (:bold t :inherit gnus-group-mail-6-empty))))
+   `(gnus-group-mail-6 ((t (:weight bold :inherit gnus-group-mail-6-empty))))
    `(gnus-group-mail-6-empty ((t (:inherit gnus-group-news-6-empty))))
-   `(gnus-group-mail-low ((t (:bold t :inherit gnus-group-mail-low-empty))))
+   `(gnus-group-mail-low ((t (:weight bold :inherit gnus-group-mail-low-empty))))
    `(gnus-group-mail-low-empty ((t (:inherit gnus-group-news-low-empty))))
-   `(gnus-group-news-1 ((t (:bold t :inherit gnus-group-news-1-empty))))
-   `(gnus-group-news-2 ((t (:bold t :inherit gnus-group-news-2-empty))))
-   `(gnus-group-news-3 ((t (:bold t :inherit gnus-group-news-3-empty))))
-   `(gnus-group-news-4 ((t (:bold t :inherit gnus-group-news-4-empty))))
-   `(gnus-group-news-5 ((t (:bold t :inherit gnus-group-news-5-empty))))
-   `(gnus-group-news-6 ((t (:bold t :inherit gnus-group-news-6-empty))))
-   `(gnus-group-news-low ((t (:bold t :inherit gnus-group-news-low-empty))))
+   `(gnus-group-news-1 ((t (:weight bold :inherit gnus-group-news-1-empty))))
+   `(gnus-group-news-2 ((t (:weight bold :inherit gnus-group-news-2-empty))))
+   `(gnus-group-news-3 ((t (:weight bold :inherit gnus-group-news-3-empty))))
+   `(gnus-group-news-4 ((t (:weight bold :inherit gnus-group-news-4-empty))))
+   `(gnus-group-news-5 ((t (:weight bold :inherit gnus-group-news-5-empty))))
+   `(gnus-group-news-6 ((t (:weight bold :inherit gnus-group-news-6-empty))))
+   `(gnus-group-news-low ((t (:weight bold :inherit gnus-group-news-low-empty))))
    `(gnus-header-content ((t (:inherit message-header-other))))
    `(gnus-header-from ((t (:inherit message-header-to))))
    `(gnus-header-name ((t (:inherit message-header-name))))
@@ -630,7 +678,34 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(hydra-face-blue ((t (:foreground ,zenburn-blue :background ,zenburn-bg))))
    `(hydra-face-pink ((t (:foreground ,zenburn-magenta :background ,zenburn-bg))))
    `(hydra-face-teal ((t (:foreground ,zenburn-cyan :background ,zenburn-bg))))
-;;;; ivy
+;;;;; info+
+   `(info-command-ref-item ((t (:background ,zenburn-bg-1 :foreground ,zenburn-orange))))
+   `(info-constant-ref-item ((t (:background ,zenburn-bg-1 :foreground ,zenburn-magenta))))
+   `(info-double-quoted-name ((t (:inherit font-lock-comment-face))))
+   `(info-file ((t (:background ,zenburn-bg-1 :foreground ,zenburn-yellow))))
+   `(info-function-ref-item ((t (:background ,zenburn-bg-1 :inherit font-lock-function-name-face))))
+   `(info-macro-ref-item ((t (:background ,zenburn-bg-1 :foreground ,zenburn-yellow))))
+   `(info-menu ((t (:foreground ,zenburn-yellow))))
+   `(info-quoted-name ((t (:inherit font-lock-constant-face))))
+   `(info-reference-item ((t (:background ,zenburn-bg-1))))
+   `(info-single-quote ((t (:inherit font-lock-keyword-face))))
+   `(info-special-form-ref-item ((t (:background ,zenburn-bg-1 :foreground ,zenburn-yellow))))
+   `(info-string ((t (:inherit font-lock-string-face))))
+   `(info-syntax-class-item ((t (:background ,zenburn-bg-1 :foreground ,zenburn-blue+1))))
+   `(info-user-option-ref-item ((t (:background ,zenburn-bg-1 :foreground ,zenburn-red))))
+   `(info-variable-ref-item ((t (:background ,zenburn-bg-1 :foreground ,zenburn-orange))))
+;;;;; irfc
+   `(irfc-head-name-face ((t (:foreground ,zenburn-red :weight bold))))
+   `(irfc-head-number-face ((t (:foreground ,zenburn-red :weight bold))))
+   `(irfc-reference-face ((t (:foreground ,zenburn-blue-1 :weight bold))))
+   `(irfc-requirement-keyword-face ((t (:inherit font-lock-keyword-face))))
+   `(irfc-rfc-link-face ((t (:inherit link))))
+   `(irfc-rfc-number-face ((t (:foreground ,zenburn-cyan :weight bold))))
+   `(irfc-std-number-face ((t (:foreground ,zenburn-green+4 :weight bold))))
+   `(irfc-table-item-face ((t (:foreground ,zenburn-green+3))))
+   `(irfc-title-face ((t (:foreground ,zenburn-yellow
+                                      :underline t :weight bold))))
+;;;;; ivy
    `(ivy-confirm-face ((t (:foreground ,zenburn-green :background ,zenburn-bg))))
    `(ivy-match-required-face ((t (:foreground ,zenburn-red :background ,zenburn-bg))))
    `(ivy-remote ((t (:foreground ,zenburn-blue :background ,zenburn-bg))))
@@ -684,9 +759,13 @@ Also bind `class' to ((class color) (min-colors 89))."
 ;;;;; ledger-mode
    `(ledger-font-payee-uncleared-face ((t (:foreground ,zenburn-red-1 :weight bold))))
    `(ledger-font-payee-cleared-face ((t (:foreground ,zenburn-fg :weight normal))))
+   `(ledger-font-payee-pending-face ((t (:foreground ,zenburn-red :weight normal))))
    `(ledger-font-xact-highlight-face ((t (:background ,zenburn-bg+1))))
+   `(ledger-font-auto-xact-face ((t (:foreground ,zenburn-yellow-1 :weight normal))))
+   `(ledger-font-periodic-xact-face ((t (:foreground ,zenburn-green :weight normal))))
    `(ledger-font-pending-face ((t (:foreground ,zenburn-orange weight: normal))))
    `(ledger-font-other-face ((t (:foreground ,zenburn-fg))))
+   `(ledger-font-posting-date-face ((t (:foreground ,zenburn-orange :weight normal))))
    `(ledger-font-posting-account-face ((t (:foreground ,zenburn-blue-1))))
    `(ledger-font-posting-account-cleared-face ((t (:foreground ,zenburn-fg))))
    `(ledger-font-posting-account-pending-face ((t (:foreground ,zenburn-orange))))
@@ -700,6 +779,10 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(ledger-font-report-clickable-face ((t (:foreground ,zenburn-orange :weight normal))))
 ;;;;; linum-mode
    `(linum ((t (:foreground ,zenburn-green+2 :background ,zenburn-bg))))
+;;;;; lispy
+   `(lispy-command-name-face ((t (:background ,zenburn-bg-05 :inherit font-lock-function-name-face))))
+   `(lispy-cursor-face ((t (:foreground ,zenburn-bg :background ,zenburn-fg))))
+   `(lispy-face-hint ((t (:inherit highlight :foreground ,zenburn-yellow))))
 ;;;;; ruler-mode
    `(ruler-mode-column-number ((t (:inherit 'ruler-mode-default :foreground ,zenburn-fg))))
    `(ruler-mode-fill-column ((t (:inherit 'ruler-mode-default :foreground ,zenburn-yellow))))
@@ -851,7 +934,11 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(mingus-pausing-face ((t (:foreground ,zenburn-magenta))))
    `(mingus-playing-face ((t (:foreground ,zenburn-cyan))))
    `(mingus-playlist-face ((t (:foreground ,zenburn-cyan ))))
+   `(mingus-mark-face ((t (:bold t :foreground ,zenburn-magenta))))
    `(mingus-song-file-face ((t (:foreground ,zenburn-yellow))))
+   `(mingus-artist-face ((t (:foreground ,zenburn-cyan))))
+   `(mingus-album-face ((t (:underline t :foreground ,zenburn-red+1))))
+   `(mingus-album-stale-face ((t (:foreground ,zenburn-red+1))))
    `(mingus-stopped-face ((t (:foreground ,zenburn-red))))
 ;;;;; nav
    `(nav-face-heading ((t (:foreground ,zenburn-yellow))))
@@ -876,6 +963,23 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(mumamo-background-chunk-submode2 ((t (:background ,zenburn-bg+2))))
    `(mumamo-background-chunk-submode3 ((t (:background ,zenburn-bg+3))))
    `(mumamo-background-chunk-submode4 ((t (:background ,zenburn-bg+1))))
+;;;;; neotree
+   `(neo-banner-face ((t (:foreground ,zenburn-blue+1 :weight bold))))
+   `(neo-header-face ((t (:foreground ,zenburn-fg))))
+   `(neo-root-dir-face ((t (:foreground ,zenburn-blue+1 :weight bold))))
+   `(neo-dir-link-face ((t (:foreground ,zenburn-blue))))
+   `(neo-file-link-face ((t (:foreground ,zenburn-fg))))
+   `(neo-expand-btn-face ((t (:foreground ,zenburn-blue))))
+   `(neo-vc-default-face ((t (:foreground ,zenburn-fg+1))))
+   `(neo-vc-user-face ((t (:foreground ,zenburn-red :slant italic))))
+   `(neo-vc-up-to-date-face ((t (:foreground ,zenburn-fg))))
+   `(neo-vc-edited-face ((t (:foreground ,zenburn-magenta))))
+   `(neo-vc-needs-merge-face ((t (:foreground ,zenburn-red+1))))
+   `(neo-vc-unlocked-changes-face ((t (:foreground ,zenburn-red :background ,zenburn-blue-5))))
+   `(neo-vc-added-face ((t (:foreground ,zenburn-green+1))))
+   `(neo-vc-conflict-face ((t (:foreground ,zenburn-red+1))))
+   `(neo-vc-missing-face ((t (:foreground ,zenburn-red+1))))
+   `(neo-vc-ignored-face ((t (:foreground ,zenburn-fg-1))))
 ;;;;; org-mode
    `(org-agenda-date-today
      ((t (:foreground ,zenburn-fg+1 :slant italic :weight bold))) t)
@@ -886,7 +990,7 @@ Also bind `class' to ((class color) (min-colors 89))."
                                    :box (:line-width 1 :style released-button)))))
    `(org-date ((t (:foreground ,zenburn-blue :underline t))))
    `(org-deadline-announce ((t (:foreground ,zenburn-red-1))))
-   `(org-done ((t (:bold t :weight bold :foreground ,zenburn-green+3))))
+   `(org-done ((t (:weight bold :weight bold :foreground ,zenburn-green+3))))
    `(org-formula ((t (:foreground ,zenburn-yellow-2))))
    `(org-headline-done ((t (:foreground ,zenburn-green+3))))
    `(org-hide ((t (:foreground ,zenburn-bg-1))))
@@ -905,11 +1009,11 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(org-sexp-date ((t (:foreground ,zenburn-blue+1 :underline t))))
    `(org-special-keyword ((t (:inherit font-lock-comment-face))))
    `(org-table ((t (:foreground ,zenburn-green+2))))
-   `(org-tag ((t (:bold t :weight bold))))
+   `(org-tag ((t (:weight bold :weight bold))))
    `(org-time-grid ((t (:foreground ,zenburn-orange))))
-   `(org-todo ((t (:bold t :foreground ,zenburn-red :weight bold))))
+   `(org-todo ((t (:weight bold :foreground ,zenburn-red :weight bold))))
    `(org-upcoming-deadline ((t (:inherit font-lock-keyword-face))))
-   `(org-warning ((t (:bold t :foreground ,zenburn-red :weight bold :underline nil))))
+   `(org-warning ((t (:weight bold :foreground ,zenburn-red :weight bold :underline nil))))
    `(org-column ((t (:background ,zenburn-bg-1))))
    `(org-column-title ((t (:background ,zenburn-bg-1 :underline t :weight bold))))
    `(org-mode-line-clock ((t (:foreground ,zenburn-fg :background ,zenburn-bg-1))))
@@ -995,12 +1099,19 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(rcirc-server-prefix ((t (:foreground ,zenburn-green+1))))
    `(rcirc-timestamp ((t (:foreground ,zenburn-green+2))))
    `(rcirc-nick-in-message ((t (:foreground ,zenburn-yellow))))
-   `(rcirc-nick-in-message-full-line ((t (:bold t))))
-   `(rcirc-prompt ((t (:foreground ,zenburn-yellow :bold t))))
+   `(rcirc-nick-in-message-full-line ((t (:weight bold))))
+   `(rcirc-prompt ((t (:foreground ,zenburn-yellow :weight bold))))
    `(rcirc-track-nick ((t (:inverse-video t))))
-   `(rcirc-track-keyword ((t (:bold t))))
-   `(rcirc-url ((t (:bold t))))
-   `(rcirc-keyword ((t (:foreground ,zenburn-yellow :bold t))))
+   `(rcirc-track-keyword ((t (:weight bold))))
+   `(rcirc-url ((t (:weight bold))))
+   `(rcirc-keyword ((t (:foreground ,zenburn-yellow :weight bold))))
+;;;;; re-builder
+   `(reb-match-0 ((t (:foreground ,zenburn-bg :background ,zenburn-magenta))))
+   `(reb-match-1 ((t (:foreground ,zenburn-bg :background ,zenburn-blue))))
+   `(reb-match-2 ((t (:foreground ,zenburn-bg :background ,zenburn-orange))))
+   `(reb-match-3 ((t (:foreground ,zenburn-bg :background ,zenburn-red))))
+;;;;; regex-tool
+   `(regex-tool-matched-face ((t (:background ,zenburn-blue-4 :weight bold))))
 ;;;;; rpm-mode
    `(rpm-spec-dir-face ((t (:foreground ,zenburn-green))))
    `(rpm-spec-doc-face ((t (:foreground ,zenburn-green))))
@@ -1019,7 +1130,7 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(rst-level-5-face ((t (:foreground ,zenburn-cyan))))
    `(rst-level-6-face ((t (:foreground ,zenburn-green-1))))
 ;;;;; sh-mode
-   `(sh-heredoc     ((t (:foreground ,zenburn-yellow :bold t))))
+   `(sh-heredoc     ((t (:foreground ,zenburn-yellow :weight bold))))
    `(sh-quoted-exec ((t (:foreground ,zenburn-red))))
 ;;;;; show-paren
    `(show-paren-mismatch ((t (:foreground ,zenburn-red+1 :background ,zenburn-bg+3 :weight bold))))
@@ -1114,6 +1225,13 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(undo-tree-visualizer-default-face ((t (:foreground ,zenburn-fg))))
    `(undo-tree-visualizer-register-face ((t (:foreground ,zenburn-yellow))))
    `(undo-tree-visualizer-unmodified-face ((t (:foreground ,zenburn-cyan))))
+;;;;; visual-regexp
+   `(vr/group-0 ((t (:foreground ,zenburn-bg :background ,zenburn-green :weight bold))))
+   `(vr/group-1 ((t (:foreground ,zenburn-bg :background ,zenburn-orange :weight bold))))
+   `(vr/group-2 ((t (:foreground ,zenburn-bg :background ,zenburn-blue :weight bold))))
+   `(vr/match-0 ((t (:inherit isearch))))
+   `(vr/match-1 ((t (:foreground ,zenburn-yellow-2 :background ,zenburn-bg-1 :weight bold))))
+   `(vr/match-separator-face ((t (:foreground ,zenburn-red :weight bold))))
 ;;;;; volatile-highlights
    `(vhl/default-face ((t (:background ,zenburn-bg-05))))
 ;;;;; web-mode
@@ -1207,6 +1325,8 @@ Also bind `class' to ((class color) (min-colors 89))."
    `(nrepl-message-colors
      '(,zenburn-red ,zenburn-orange ,zenburn-yellow ,zenburn-green ,zenburn-green+4
                     ,zenburn-cyan ,zenburn-blue+1 ,zenburn-magenta))
+;;;;; pdf-tools
+   `(pdf-view-midnight-colors '(,zenburn-fg . ,zenburn-bg-05))
 ;;;;; vc-annotate
    `(vc-annotate-color-map
      '(( 20. . ,zenburn-red-1)
